# fontello font demo

show codes
 icon-circles0xe800
 icon-home0xe801
 icon-help-circle0xe802
 icon-book0xe803
 icon-github-circled0xe804
 icon-cancel-circled0xe805
 icon-dot-circled0xe806
 icon-circle-empty0xe807
 icon-check-off0xe808
 icon-check-on0xe809
 icon-ok-circled0xe80a
 icon-angle-circled-right0xe80b
 icon-pencil0xe80c
 icon-doc0xe80d
 icon-doc-inv0xe80e
 icon-hamburger0xe80f
 icon-cog0xe810
 icon-left0xe811
 icon-menu-outline0xe812
 icon-plus-circle0xe813
 icon-down-circle0xe814
 icon-up-circle0xe815
 icon-angle-circled-left0xe816
 icon-trash0xe817
 icon-chart-line0xe818
 icon-download0xe819
 icon-user0xe81a
 icon-menu0xe81b
 icon-sidebar0xe81c
 icon-sidebar-open0xe81d
 icon-lightbulb0xe81e
 icon-mail0xe81f
 icon-key0xe820
 icon-logout0xe821
 icon-spin60xe822
 icon-share0xe828
 icon-twitter0xf099
 icon-facebook0xf230